Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: chrome/browser/resources/options/chromeos/quick_unlock_configure_overlay.js

Issue 2787153002: MD Settings: Move easy unlock from people to lock screen. (Closed)
Patch Set: Closure. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/resources/options/compiled_resources.gyp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/resources/options/chromeos/quick_unlock_configure_overlay.js
diff --git a/chrome/browser/resources/options/chromeos/quick_unlock_configure_overlay.js b/chrome/browser/resources/options/chromeos/quick_unlock_configure_overlay.js
index 6e461404674a9ba555e5a909d6bd0619ecdc22f3..7a5f37e296e0b9aae08f28d49024ad2248c726ad 100644
--- a/chrome/browser/resources/options/chromeos/quick_unlock_configure_overlay.js
+++ b/chrome/browser/resources/options/chromeos/quick_unlock_configure_overlay.js
@@ -74,9 +74,11 @@ cr.define('options', function() {
var screenLockDiv = lockScreen.root.querySelector('#screenLockDiv');
screenLockDiv.hidden = true;
// The fingerprint settings on options is always hidden.
var fingerprintDiv = lockScreen.root.querySelector('#fingerprintDiv');
fingerprintDiv.hidden = true;
+ var easyUnlockDiv = lockScreen.root.querySelector('#easyUnlock');
+ easyUnlockDiv.hidden = true;
var passwordPrompt = lockScreen.root.
querySelector('settings-password-prompt-dialog');
« no previous file with comments | « no previous file | chrome/browser/resources/options/compiled_resources.gyp » ('j') | no next file with comments »
@@ -74,9 +74,11 @@ cr.define('options', function() {
var screenLockDiv = lockScreen.root.querySelector('#screenLockDiv');
screenLockDiv.hidden = true;
- // The fingerprint settings on options is always hidden.
+ // The fingerprint settings and easy unlock on options is always hidden.
var fingerprintDiv = lockScreen.root.querySelector('#fingerprintDiv');
fingerprintDiv.hidden = true;

Powered by Google App Engine
This is Rietveld 408576698